@@ -1,9 +1,9 @@
 package MIDI::Ngram;
 our $AUTHORITY = 'cpan:GENE';
 
-# ABSTRACT: Find the top repeated note phrases of a MIDI file
+# ABSTRACT: Find the top repeated note phrases of MIDI files
 
-our $VERSION = '0.1105';
+our $VERSION = '0.1106';
 
 use Moo;
 use strictures 2;
@@ -61,6 +61,13 @@ has patches => (
 );
 
 
+has random_patch => (
+    is      => 'ro',
+    isa     => \&_is_boolean,
+    default => sub { 0 },
+);
+
+
 has out_file => (
     is      => 'ro',
     default => sub { 'midi-ngram.mid' },
@@ -94,13 +101,6 @@ has weight => (
 );
 
 
-has random_patch => (
-    is      => 'ro',
-    isa     => \&_is_boolean,
-    default => sub { 0 },
-);
-
-
 has shuffle_phrases => (
     is      => 'ro',
     isa     => \&_is_boolean,
@@ -430,11 +430,11 @@ __END__
 
 =head1 NAME
 
-MIDI::Ngram - Find the top repeated note phrases of a MIDI file
+MIDI::Ngram - Find the top repeated note phrases of MIDI files
 
 =head1 VERSION
 
-version 0.1105
+version 0.1106
 
 =head1 SYNOPSIS
 
@@ -453,13 +453,13 @@ version 0.1105
   print $analysis;
 
   my $playback = $mng->populate;
+  print $playback;
 
   $mng->write;
 
   # Analyze multitrack tunes
   $mng = MIDI::Ngram->new(
     in_file     => [ '/multi/channel/tune1.mid', '/multi/channel/tune2.mid' ],
-    ngram_size  => 3,
     one_channel => 1,
   );
 
@@ -478,14 +478,14 @@ version 0.1105
 =head1 DESCRIPTION
 
 C<MIDI::Ngram> parses a given list of MIDI files, finds the top
-repeated note phrases, outputs the analysis, transition network, and
-renders them to a MIDI file if desired.
+repeated note phrases, builds the analysis, transition network, and
+renders to a MIDI file if desired.
 
 =head1 ATTRIBUTES
 
 =head2 in_file
 
-Required.  An ArrayRef of MIDI files to process.
+Required.  An Array reference of MIDI files to process.
 
 =head2 ngram_size
 
@@ -519,6 +519,12 @@ The patches to choose from (at random) if given the B<random_patch> option.
 
 Default: C<[0 .. 127]>
 
+=head2 random_patch
+
+Boolean.  Choose a random patch from B<patches> for each channel.
+
+Default: C<0> (meaning "use the piano patch")
+
 =head2 out_file
 
 MIDI output file.
@@ -533,7 +539,8 @@ Default: C<''> (no resting)
 
 =head2 analyze
 
-ArrayRef of the channels to analyze.  If not given, all channels are analyzed.
+Array reference of the channels to analyze.  If not given, all
+channels are analyzed.
 
 Default: C<undef>
 
@@ -552,12 +559,6 @@ L<List::Util::WeightedChoice/choose_weighted>.
 
 Default: C<0>
 
-=head2 random_patch
-
-Boolean.  Choose a random patch from B<patches> for each channel.
-
-Default: C<0> (meaning "use the piano patch")
-
 =head2 shuffle_phrases
 
 Boolean.  Shuffle the non-weighted phrases before playing them.
